**********
Technology
**********

Back-end:

* `Python 3 <https://www.python.org/>`_
* `Django framework <https://www.djangoproject.com/>`_
* `Django REST Framework <http://www.django-rest-framework.org/>`_
* `MongoDB <https://www.mongodb.com/>`_
* `Comet long polling <http://www.ibm.com/developerworks/library/wa-reverseajax1/>`_
* :ref:`SFChat protocol <Protocol>`
* :ref:`REST_API`
* `SSL/TLS <https://en.wikipedia.org/wiki/Transport_Layer_Security>`_

Front-end:

* `jQuery framework <https://jquery.com/>`_
* `RequireJS <http://requirejs.org/>`_
* `Normalize.css <https://necolas.github.io/normalize.css/>`_
* `Session Storage <https://developer.mozilla.org/en-US/docs/Web/API/Window/sessionStorage>`_

Requirements:

* django 1.10.4
* pymongo 3.4.0
* mongoengine 0.10.6
* djangorestframework 3.5.3
* django_compressor 1.6
* django-debug-toolbar 1.6
